==> kubernetes-model-core-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/EphemeralVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EphemeralVolumeSourceFluentImpl<A extends EphemeralVolumeSourceFluent<A>> extends BaseFluent<A> implements EphemeralVolumeSourceFluent<A>{
  public EphemeralVolumeSourceFluentImpl() {
  }
  public EphemeralVolumeSourceFluentImpl(EphemeralVolumeSource instance) {
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private PersistentVolumeClaimTemplateBuilder volumeClaimTemplate;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildVolumeClaimTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public PersistentVolumeClaimTemplate getVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null ?this.volumeClaimTemplate.build():null;
  }
  public PersistentVolumeClaimTemplate buildVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null ?this.volumeClaimTemplate.build():null;
  }
  public A withVolumeClaimTemplate(PersistentVolumeClaimTemplate volumeClaimTemplate) {
    _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate);
    if (volumeClaimTemplate!=null){ this.volumeClaimTemplate= new PersistentVolumeClaimTemplateBuilder(volumeClaimTemplate); _visitables.get("volumeClaimTemplate").add(this.volumeClaimTemplate);} else { this.volumeClaimTemplate = null; _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate); } return (A) this;
  }
  public Boolean hasVolumeClaimTemplate() {
    return this.volumeClaimTemplate != null;
  }
  public EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplate() {
    return new EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl();
  }
  public EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplateLike(PersistentVolumeClaimTemplate item) {
    return new EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl(item);
  }
  public EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate());
  }
  public EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): new PersistentVolumeClaimTemplateBuilder().build());
  }
  public EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplateLike(PersistentVolumeClaimTemplate item) {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EphemeralVolumeSourceFluentImpl that = (EphemeralVolumeSourceFluentImpl) o;
    if (volumeClaimTemplate != null ? !volumeClaimTemplate.equals(that.volumeClaimTemplate) :that.volumeClaimTemplate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(volumeClaimTemplate,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (volumeClaimTemplate != null) { sb.append("volumeClaimTemplate:"); sb.append(volumeClaimTemplate + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class VolumeClaimTemplateNestedImpl<N> extends PersistentVolumeClaimTemplateFluentImpl<EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<N>> implements EphemeralVolumeSourceFluent.VolumeClaimTemplateNested<N>,Nested<N>{
    VolumeClaimTemplateNestedImpl(PersistentVolumeClaimTemplate item) {
      this.builder = new PersistentVolumeClaimTemplateBuilder(this, item);
    }
    VolumeClaimTemplateNestedImpl() {
      this.builder = new PersistentVolumeClaimTemplateBuilder(this);
    }
    PersistentVolumeClaimTemplateBuilder builder;
    public N and() {
      return (N) EphemeralVolumeSourceFluentImpl.this.withVolumeClaimTemplate(builder.build());
    }
    public N endVolumeClaimTemplate() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/EphemeralVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EphemeralVolumeSourceFluentImpl<A extends EphemeralVolumeSourceFluent<A>> extends BaseFluent<A> implements EphemeralVolumeSourceFluent<A>{
  public EphemeralVolumeSourceFluentImpl() {
  }
  public EphemeralVolumeSourceFluentImpl(EphemeralVolumeSource instance) {
    if (instance != null) {
      this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private PersistentVolumeClaimTemplateBuilder volumeClaimTemplate;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildVolumeClaimTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public PersistentVolumeClaimTemplate getVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null ?this.volumeClaimTemplate.build():null;
  }
  public PersistentVolumeClaimTemplate buildVolumeClaimTemplate() {
    return this.volumeClaimTemplate!=null ?this.volumeClaimTemplate.build():null;
  }
  public A withVolumeClaimTemplate(PersistentVolumeClaimTemplate volumeClaimTemplate) {
    _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate);
    if (volumeClaimTemplate!=null){ this.volumeClaimTemplate= new PersistentVolumeClaimTemplateBuilder(volumeClaimTemplate); _visitables.get("volumeClaimTemplate").add(this.volumeClaimTemplate);} else { this.volumeClaimTemplate = null; _visitables.get("volumeClaimTemplate").remove(this.volumeClaimTemplate); } return (A) this;
  }
  public Boolean hasVolumeClaimTemplate() {
    return this.volumeClaimTemplate != null;
  }
  public EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplate() {
    return new EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl();
  }
  public EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<A> withNewVolumeClaimTemplateLike(PersistentVolumeClaimTemplate item) {
    return new EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNestedImpl(item);
  }
  public EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<A> editVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate());
  }
  public EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplate() {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): new PersistentVolumeClaimTemplateBuilder().build());
  }
  public EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<A> editOrNewVolumeClaimTemplateLike(PersistentVolumeClaimTemplate item) {
    return withNewVolumeClaimTemplateLike(getVolumeClaimTemplate() != null ? getVolumeClaimTemplate(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EphemeralVolumeSourceFluentImpl that = (EphemeralVolumeSourceFluentImpl) o;
    if (!java.util.Objects.equals(volumeClaimTemplate, that.volumeClaimTemplate)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(volumeClaimTemplate,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (volumeClaimTemplate != null) { sb.append("volumeClaimTemplate:"); sb.append(volumeClaimTemplate + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class VolumeClaimTemplateNestedImpl<N> extends PersistentVolumeClaimTemplateFluentImpl<EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<N>> implements EphemeralVolumeSourceFluentImpl.VolumeClaimTemplateNested<N>,Nested<N>{
    VolumeClaimTemplateNestedImpl(PersistentVolumeClaimTemplate item) {
      this.builder = new PersistentVolumeClaimTemplateBuilder(this, item);
    }
    VolumeClaimTemplateNestedImpl() {
      this.builder = new PersistentVolumeClaimTemplateBuilder(this);
    }
    PersistentVolumeClaimTemplateBuilder builder;
    public N and() {
      return (N) EphemeralVolumeSourceFluentImpl.this.withVolumeClaimTemplate(builder.build());
    }
    public N endVolumeClaimTemplate() {
      return and();
    }
    
  }
  
}
